# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

__version__ = '0.0.2'

BASE_URL = 'https://free-proxy-list.net/'
SSL_URL = 'http://sslproxies.org/'
SOCKS_URL = 'https://www.socks-proxy.net/'
TEST_URL = 'https://httpbin.org'

HTTP_DELAY = 0.2
HTTP_TIMEOUT = 6
HTTP_RETRIES = 3

LAST_CHECKED_THRESHOLD = 20
CACHE_SERVER_URL = 'http://54.162.135.16:5000/fetch'
